#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_ONEMINUS_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_ONEMINUS_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/oneminus.hpp>

#endif
